import wx
import ssglob
from ui.ids import *

class ExportTextScriptDialog(wx.Dialog):
    def __init__(self, *args, **kwds):
        # begin wxGlade: ExportTextScriptDialog.__init__
        kwds["style"] = wx.DEFAULT_DIALOG_STYLE
        wx.Dialog.__init__(self, *args, **kwds)
        self.lblStart = wx.StaticText(self, -1, "Start line #")
        self.scStart = wx.SpinCtrl(self, -1, "", min=0, max=(len(ssglob.gTextData) - 1))
        self.label_2 = wx.StaticText(self, -1, "End line #")
        self.scEnd = wx.SpinCtrl(self, -1, "", min=0, max=(len(ssglob.gTextData) - 1))
        self.cbIgnore = wx.CheckBox(self, -1, "Ignore descriptions containing:")
        self.tcIgnoreText = wx.TextCtrl(self, -1, "var")
        self.cbMustContain = wx.CheckBox(self, -1, "Description must contain:")
        self.tcMustContainText = wx.TextCtrl(self, -1, "")
        self.bOK = wx.Button(self, wx.ID_OK, "OK")
        self.bCancel = wx.Button(self, wx.ID_CANCEL, "Cancel")

        self.lTextFile = wx.StaticText(self, -1, "Text File", style=wx.ALIGN_CENTRE)
        self.tcTextFile = wx.TextCtrl(self, -1, "")
        self.bTextBrowse = wx.Button(self, ID_BUTTON_TEXT_BROWSE, "Browse")

        wx.EVT_BUTTON(self, ID_BUTTON_TEXT_BROWSE, self.buttonTextBrowse)

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: ExportTextScriptDialog.__set_properties
        self.SetTitle("Export Text Script")
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: ExportTextScriptDialog.__do_layout
        szMain = wx.BoxSizer(wx.VERTICAL)
        szBottom = wx.BoxSizer(wx.HORIZONTAL)
        szMiddle = wx.BoxSizer(wx.HORIZONTAL)
        szMiddleRight = wx.BoxSizer(wx.VERTICAL)
        szMiddleLeft = wx.BoxSizer(wx.VERTICAL)
        szTop = wx.BoxSizer(wx.HORIZONTAL)
        szTopRight = wx.BoxSizer(wx.VERTICAL)
        szTopMid = wx.BoxSizer(wx.VERTICAL)
        szTopLeft = wx.BoxSizer(wx.VERTICAL)

        szTopLeft.Add(self.lblStart, 0, 0, 0)
        szTopLeft.Add(self.scStart, 0, 0, 0)
        szTop.Add(szTopLeft, 1, wx.EXPAND, 0)

        szTopMid.Add(self.label_2, 0, 0, 0)
        szTopMid.Add(self.scEnd, 0, 0, 0)
        szTop.Add(szTopMid, 1, wx.EXPAND, 0)

        szTopRight.Add(self.cbIgnore, 0, wx.ALIGN_RIGHT, 0)
        szTopRight.Add(self.tcIgnoreText, 0, wx.ALIGN_RIGHT, 0)
        szTop.Add(szTopRight, 1, wx.EXPAND, 0)

        szMain.Add(szTop, 1, wx.EXPAND, 0)

        # Middle row
        szMiddleLeft.Add(self.lTextFile, 0, wx.ALIGN_CENTER_VERTICAL|wx.FIXED_MINSIZE, 0)
        szMiddleLeft.Add(self.tcTextFile, 0, wx.ALIGN_CENTER_VERTICAL|wx.FIXED_MINSIZE, 0)
        szMiddleLeft.Add(self.bTextBrowse, 0, wx.ALIGN_CENTER_VERTICAL|wx.FIXED_MINSIZE, 0)
        szMiddle.Add(szMiddleLeft, 1, wx.EXPAND, 0)

        szMiddleRight.Add(self.cbMustContain, 0, wx.ALIGN_RIGHT, 0)
        szMiddleRight.Add(self.tcMustContainText, 0, wx.ALIGN_RIGHT, 0)
        szMiddle.Add(szMiddleRight, 1, wx.EXPAND, 0)

        szMain.Add(szMiddle, 1, wx.EXPAND, 0)

        # Bottom row
        szBottom.Add(self.bOK, 0, 0, 0)
        szBottom.Add(self.bCancel, 0, 0, 0)
        szMain.Add(szBottom, 1, wx.ALIGN_RIGHT, 0)
        self.SetSizer(szMain)
        szMain.Fit(self)
        self.Layout()
        # end wxGlade

    def buttonTextBrowse(self, event):
        sd = wx.FileDialog(self,
                           "Save output text",
                           wildcard="TXT files (*.txt)|*.txt|All Files|*.*",
                           style=wx.SAVE|wx.OVERWRITE_PROMPT|wx.CHANGE_DIR)
        if sd.ShowModal() == wx.ID_OK:
            filename = sd.GetPath()
            self.tcTextFile.SetValue(filename)

    def getRange(self):
        return (self.scStart.GetValue(), self.scEnd.GetValue())

    def ignoreText(self):
        """ Returns None if text should not be ignored, otherwise a string. """
        if self.cbIgnore.IsChecked():
            return self.tcIgnoreText.GetValue()
        else:
            return None

    def containsText(self):
        """ Returns None if descriptions don't have to contain a certain string, otherwise a string. """
        if self.cbMustContain.IsChecked():
            return self.tcMustContainText.GetValue()
        else:
            return None

    def getTextFilename(self):
        return self.tcTextFile.GetValue()

# end of class ExportTextScriptDialog